import os
from subprocess import check_output

__all__ = ['celery_app', 'get_revision', '__build__', '__version__']


@property
def celery_app():
    from .celery import app
    return app


def _get_git_revision(path):
    if not os.path.exists(os.path.join(path, '.git')):
        return None
    try:
        revision = check_output(['git', 'rev-parse', 'HEAD'], cwd=path, env=os.environ)
    except Exception:
        # binary didn't exist, wasn't on path, etc
        return None
    return revision.strip().decode()


def get_revision():
    package_dir = os.path.dirname(__file__)
    checkout_dir = os.path.normpath(os.path.join(package_dir, os.pardir))
    path = os.path.join(checkout_dir)
    if os.path.exists(path):
        return _get_git_revision(path)
    return None


def get_version():
    if __build__:
        return '%s.%s' % (__version__, __build__)
    return __version__


try:
    VERSION = __import__('pkg_resources').get_distribution('clariweb').version
except Exception as e:
    VERSION = 'unknown'


__version__ = VERSION
__build__ = get_revision()