# -*- coding: utf-8 -*-

from django.utils import timezone
from clariweb.clariweb.models import DocumentAccessLog, AccessLog, DocumentPerUser


def get_client_ip(request):
    return request.META.get("REMOTE_ADDR", "")


def login_success(request):
    user = request.user
    if user and not user.is_anonymous:
        AccessLog.objects.create(user=user,
                                 message="AUTH_OK",
                                 ip=get_client_ip(request))


def login_error(request, username):
    AccessLog.objects.create(user=None,
                             username=username,
                             message="AUTH_BAD",
                             ip=get_client_ip(request))


def document_access(request, document):
    user = request.user
    clariwebuser = user.clariwebuser
    # Do not track staff users testing permissions.
    if not request.session.get("was_staff") and clariwebuser:
        DocumentAccessLog.objects.create(user=user.clariwebuser,
                                         document=document,
                                         ip=get_client_ip(request))
        dpus = DocumentPerUser.objects.filter(
            user=request.user.clariwebuser, document=document
        )
        dpus.update(last_seen=timezone.now(), seen_since_modified=True)
