# -*- coding: utf-8 -*-

from rest_framework import serializers
from clariweb.clariweb.models import Document, DocumentPerUser
from clariweb.api.serializers import DocumentSerializer


class ClinicDocumentDetailSerializer(DocumentSerializer):
    class Meta:
        model = Document
        fields = (
            'id',
            'sil_demande_number', 'sil_demande_date',
            'date_add', 'content_type',
            'document', 'patient', 'medecin', 'correspondant',
            'user', 'is_invoice', 'analyses', 'unpaid_amount',
            'clinic_bed', 'clinic_hospi', 'clinic_ipp',
            'structured_results',
        )

    structured_results = serializers.SerializerMethodField()

    def get_structured_results(self, obj):
        sr = obj.read_structured_results()
        return sr if sr else []


class ClinicDocumentSerializer(DocumentSerializer):
    class Meta:
        model = Document
        fields = (
            'id',
            'sil_demande_number', 'sil_demande_date',
            'date_add', 'content_type',
            'document', 'patient', 'medecin', 'correspondant',
            'user', 'is_invoice', 'analyses', 'unpaid_amount',
            'clinic_bed', 'clinic_hospi', 'clinic_ipp',
        )


class ClinicDocumentPerUserSerializer(DocumentSerializer):
    class Meta:
        model = DocumentPerUser
        fields = ('document', 'updated', 'last_seen', 'foreign', 'seen_since_modified')

    document = ClinicDocumentSerializer()
