# -*- coding: utf-8 -*-

from rest_framework import mixins, viewsets, generics
from django_filters.rest_framework import DjangoFilterBackend
from clariweb.api.clinic.serializers import (
    ClinicDocumentPerUserSerializer,
    ClinicDocumentDetailSerializer,
)
from clariweb.api.clinic.pagination import ClinicDocumentListPagination
from clariweb.api.clinic.filters import ClinicFilter
from clariweb.clariweb.models import Document, DocumentPerUser


class ListDocumentClinicView(generics.ListAPIView):
    serializer_class = ClinicDocumentPerUserSerializer
    filter_backends = (DjangoFilterBackend, )
    filterset_class = ClinicFilter
    pagination_class = ClinicDocumentListPagination

    def get_queryset(self):
        qs = DocumentPerUser.objects.foruser(
            user=self.request.user, shareservices=True)
        qs = qs.filter(document__document="Compte-Rendu PDF")
        qs = qs.filter(user__kind="COR")
        return qs


class ListDocumentClinicNoShareServicesView(ListDocumentClinicView):
    def get_queryset(self):
        return super().get_queryset().filter(foreign=False)


class DocumentClinicDetailView(mixins.RetrieveModelMixin,
                               viewsets.GenericViewSet):
    serializer_class = ClinicDocumentDetailSerializer

    def get_queryset(self):
        return Document.objects.foruser(self.request.user)
