# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import hashlib
from rest_framework import serializers
from django.conf import settings
from clariweb.clariweb.models import PaymentRequest, PaymentResponse


class PaymentRequestSerializer(serializers.ModelSerializer):
    class Meta:
        model = PaymentRequest
        fields = (
            'vads_amount',
            'vads_cust_id',
            'vads_cust_title',
            'vads_cust_email',
            'vads_cust_last_name',
            'vads_cust_first_name',
            'vads_capture_delay',
            'vads_payment_config',
            'vads_language',
            'vads_return_mode',
            'vads_redirect_success_timeout',
            'vads_redirect_success_message',
            'vads_redirect_error_timeout',
            'vads_redirect_error_message',
            'vads_url_success',
            'vads_url_referral',
            'vads_url_refused',
            'vads_url_cancel',
            'vads_url_error',
            'vads_url_return',
            'vads_trans_id',
            'vads_trans_date',
            'vads_site_id',
            'vads_ctx_mode',
            'vads_currency',
            'vads_action_mode',
            'vads_page_action',
            'vads_version',
            'vads_validation_mode',
            'vads_contrib',
            'signature'
        )

    def get_signature(self, paymentrequest):
        fields = []
        for field in sorted(self.Meta.fields):
            if field.startswith("vads_"):
                value = getattr(paymentrequest, field)
                if value is None:
                    value = ''
                fields.append("{}".format(value))
        fields.append(settings.VADS_CERTIFICATE)
        return hashlib.sha1("+".join(fields).encode("utf-8")).hexdigest()


class PaymentRequestListSerializer(serializers.ModelSerializer):
    class Meta:
        model = PaymentRequest
        fields = (
            'vads_amount',
            'vads_trans_id',
            'date_insert',
            'status',
        )
    status = serializers.SerializerMethodField()

    def get_status(self, pr):
        response = pr.response
        if not response:
            return "waiting"
        else:
            if response.payment_successful:
                return "paid"
            else:
                return "refused"


class PaymentResponseSerializer(serializers.ModelSerializer):
    class Meta:
        model = PaymentResponse
        fields = "__all__"
