# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand, CommandError
from optparse import make_option
from clariweb.clariweb.models import BasicUser, ClariwebUser


class Command(BaseCommand):
    help = "Create a clariweb staffuser"

    def add_arguments(self, parser):
        parser.add_argument("--username")
        parser.add_argument("--password")
        parser.add_argument("--staff", action="store_true")
        parser.add_argument("--email")
        parser.add_argument("--sil_id", default=0, type=int,
                    help="identifiant clariweb dans clarilab")

    def handle(self, *args, **options):
        for field in ("username", "password", "email"):
            if not options.get(field):
                raise CommandError("%s is required." % (field, ))

        if BasicUser.objects.filter(username=options["username"]).count() > 0:
            raise CommandError(
                "User %s already exists." % (options["username"], ))
        if ClariwebUser.objects.filter(sil_pk=options["sil_id"]).count() > 0:
            raise CommandError(
                "User with sil_id=%s already exists." % (options["sil_id"]))

        user = BasicUser.objects.create_user(
            username=options["username"],
            password=options["password"],
            email=options["email"])
        clariwebuser = ClariwebUser(**{
            "sil_pk": options["sil_id"],
            "kind": "MED"
        })
        clariwebuser.save()
        user.clariwebuser = clariwebuser
        user.is_staff = True
        user.confirm_email(user.confirmation_key, user.email)
        user.save()
        self.stdout.write("User '%s' created." % (options["username"]), )
