# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand, CommandError
from clariweb.clariweb.models import Document


class Command(BaseCommand):
    help = "Purge documents from the system older than the specified time"

    def add_arguments(self, parser):

        parser.add_argument(
            "--max_used_space",
            type=int,
            help="Maximum space that should be used by clariweb."
                 "(size in MiB)"
        )
        parser.add_argument(
            "--perdocument_storage_used",
            type=int,
            default=200,
            help="Estimated storage space used by one document in kilobytes."
        )

    def handle(self, *args, **options):
        max_used_space = options.get("max_used_space")
        if not max_used_space:
            raise CommandError("--max_used_space is required.")
        perdocument_storage_used = options.get("perdocument_storage_used")

        document_count = Document.objects.count()
        # estimated_storage_used = (
        #     document_count * (perdocument_storage_used * 1024))
        maximum_estimated_document_count = int(
            (max_used_space * 1024 * 1024) // (perdocument_storage_used * 1024))
        # print(
        #     "estimated_storage_used: {} "
        #     "maximum_estimated_document_count: {}".format(
        #         estimated_storage_used, maximum_estimated_document_count))
        toremove_count = document_count - maximum_estimated_document_count
        if toremove_count <= 0:
            print(
                "No need to remove any document."
                "We have plenty of free storage.")
            return

        print(
            "According to our guestimate we need to remove "
            "%d documents out of %d in total." % (
                toremove_count, document_count))

        removed_documents = 0
        while removed_documents < toremove_count:
            limit = 100
            toremove_left = toremove_count - removed_documents
            if toremove_left < limit:
                limit = toremove_left
            documents = Document.objects.order_by("date_add")[:limit] \
                .only("datafile", "id")
            for doc in documents:
                doc.datafile.delete(save=False)
            Document.objects.filter(id__in=[d.id for d in documents]).delete()
            removed_documents += len(documents)
