# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand, CommandError
from django.core.validators import validate_email
from django.core.exceptions import ValidationError
from clariweb.clariweb.models import BasicUser
from django.utils import timezone


class Command(BaseCommand):
    help = "Re-send all users email confirmations"

    def add_arguments(self, parser):
        parser.add_argument(
            "--notafter",
            help="Don't resend confirmations sent after this date. "
                 "(YYYYmmddHHMM)"
        )

    def handle(self, *args, **options):
        max_date_string = options.get("notafter")
        if not max_date_string:
            raise CommandError("notafter is required.")

        max_date = timezone.make_aware(
            timezone.datetime.strptime(
                max_date_string, "%Y%m%d%H%M"),
            timezone.get_default_timezone())
        users = BasicUser.objects.exclude(email=None)
        users = users.exclude(email='').order_by("-id")
        # LC:
        # Very bad performance code, I know, but it's a One off.
        # Does not matter.
        for user in users:
            try:
                try:
                    validate_email(user.email)
                except ValidationError:
                    continue
                address = user.email_address_set.get(email=user.email)
                if address.set_at < max_date:
                    print("Reset email user id=%s email=%s" % (
                        user.id, user.email))
                    user.reset_email_confirmation(user.email)
                    user.send_email_confirmation()
            except:
                print("Error sending email reset to user id=%s email=%s" % (
                    user.id, user.email))
