# -*- coding: utf-8 -*-

import pytest
import constance
from django.core.cache import cache
from django.test import TestCase, Client
from django.urls import reverse
from .models import BasicUser


class UserTestCase(TestCase):
    def tearDown(self):
        cache.clear()

    def setUp(self):
        self.su = BasicUser.objects.create_superuser(
            username="root", password="root")
        self.nobody = BasicUser.objects.create_user(
            username="nobody", password="nobody", email="nobody@nomail.com")
        self.su_client = Client(REMOTE_ADDR="127.0.0.1")
        self.su_client.login(username='root', password='root')

        self.nobody_client = Client(REMOTE_ADDR="127.0.0.1")
        self.nobody_client.login(username='nobody', password='nobody')
        constance.config.SECURITY_IP_ADDRESSES_ADMIN = ["127.0.0.0/8"]

    def test_createuser_fail(self):
        with pytest.raises(ValueError):
            BasicUser.objects.create_user(username="")
        with pytest.raises(ValueError):
            BasicUser.objects.create_user(username=None)
        with pytest.raises(TypeError):
            BasicUser.objects.create_user()

    def test_superuser_login(self):
        c = Client()
        r = c.post(reverse('api-login'), data={
            "username": "root", "password": "root"})
        self.assertEqual(r.status_code, 200, r)
        r = c.get(reverse('api-logout'))
        self.assertEqual(r.status_code, 200, r)

    def test_createuser_noemail(self):
        u = BasicUser.objects.create_user(
            username="noemail", password="noemail", email="")
        u.save()
        u.email = ''
        u.save()

    def test_user_login(self):
        c = Client()
        r = c.post(reverse('api-login'), data={
            "username": "nobody", "password": "nobody"})
        self.assertEqual(r.status_code, 200)
        r = c.get(reverse('api-logout'))
        self.assertEqual(r.status_code, 200)

    def test_basicuser(self):
        self.su.first_name = "Jean"
        self.su.last_name = "Monnet"
        self.assertEqual(self.su.get_full_name(), "Jean Monnet")
