var pdfjs = require('pdfjs-dist/webpack.js');

angular.module('clariweb.components', [])
.run(function($templateCache) {
    $templateCache.put('partials/analyse_popover.tpl.html', require('../partials/analyse_popover.tpl.html'));
    $templateCache.put('partials/anormalite_popover.tpl.html', require('../partials/anormalite_popover.tpl.html'));
})

.component('pdf', {
    template: `
        <div>
            <div id="pdf-container" on-size-changed="$ctrl.resized">
            </div>
        </div>
        <p ng-show="$ctrl.downloaderror">Le document n'a pas pu être téléchargé.</p>

    `,
    controller: function($timeout, ClariwebAuth) {
        this.container = null;
        this.downloaderror = false;
        this.renderPage = (page, canvas) => {
            var scale = 2;
            var viewport = page.getViewport(scale);
            var context = canvas.getContext('2d');
            var renderContext = {
                canvasContext: context,
                viewport: viewport,
                enableWebGL: true,
                renderInteractiveForms: false
            };
            canvas.height = viewport.height;
            canvas.width = viewport.width;
            page.render(renderContext);
            this.resized();
        };

        this.renderPDF = (url) => {
            var sessionid = ClariwebAuth.get_sessionid();
            if (!sessionid) {
                return;
            }
            this.downloaderror = false;
            pdfjs.getDocument({
                url: url,
                httpHeaders: {'X-Session-Id': sessionid}
            }).then((_pdf) => {
                this.pdf = _pdf;
                for(var current_page = 1; current_page <= this.pdf.pdfInfo.numPages; current_page ++) {
                    const canvas = document.createElement('canvas');
                    canvas.className = 'canvas-pdf';
                    this.container.appendChild(canvas);
                    this.pdf.getPage(current_page).then((page) => {
                        this.renderPage(page, canvas);
                    });
                }
            }, (e) => {
                this.downloaderror = true;
                console.log('Error while loading the PDF', e.message);
            });

        };
        this.$onInit = () => {
            this.container = document.getElementById('pdf-container');
        };
        this.$onChanges = () => {
            if (this.container) {
                while (this.container.firstChild) {
                    this.container.removeChild(this.container.firstChild);
                }
            }
            if (this.url) {
                this.renderPDF(this.url);
            }
        };
        this.resized = () => {
            for (let element of this.container.childNodes) {
                if (element.style) {
                    element.style.width = this.container.clientWidth.toString() + 'px';
                }
            }
        };
    },
    bindings: {
        'url': '<',
    }
})


.component('clariwebusername', {
    transclude: true,
    bindings: {
        user: '<'
    },
    template: `<div>{{$ctrl.user.civilite}} {{$ctrl.user.last_name}} {{$ctrl.user.first_name}}</div>`
})

.component('datenaissance', {
    bindings: {
        date_naissance: '<date'
    },
    transclude: true,
    template: `
        <div>
            <div ng-show="$ctrl.date_naissance">
                Né(e) le {{$ctrl.date_naissance | date:\'dd/MM/yyyy\'}}
                ({{$ctrl.date_naissance|age}} ans)
            </div>
            <div ng-show="!$ctrl.date_naissance">
                Aucune date de naissance n\'a été saisie.
            </div>
        </div>`
    }
)

.component('yesno', {
    bindings: {
        value: '<'
    },
    transclude: true,
    template: `
        <span class="label" ng-class="{'label-success': $ctrl.value, 'label-warning': !$ctrl.value}">
            <i class="fa" ng-class="{'fa-check': $ctrl.value, 'fa-times': !$ctrl.value}"></i> {{$ctrl.value ? 'OUI' : 'NON'}}
        </span>`
    }
)

.component('clariwebuseraddress', {
    bindings: {
        user: '<'
    },
    transclude: true,
    controller: () => {
        this.$onInit = () => {
            this.showaddress = false;
        };
        this.$onChanges = (changes) => {
            if (changes.user) {
                let user = this.user;
                this.showaddress = user && (user.address_line1 || user.address_line2 || user.address_line3);
            }
        };
    },
    template: `
        <address>
            <div ng-show="$ctrl.showaddress"><strong>Adresse:</strong><br>
                <span ng-show="$ctrl.user.address_line1">{{$ctrl.user.address_line1}}<br></span>
                <span ng-show="$ctrl.user.address_line2">{{$ctrl.user.address_line2}}<br></span>
                <span ng-show="$ctrl.user.address_line3">{{$ctrl.user.address_line3}}<br></span>
            </div>
            <span ng-show="$ctrl.user.address_country"><strong>Pays</strong>: {{$ctrl.user.address_country}}<br></span>
            <span ng-show="$ctrl.user.address_phone"><strong>Téléphone</strong>: {{$ctrl.user.address_phone}}<br></span>
            <span ng-show="$ctrl.user.address_phone_gsm"><strong>Gsm</strong>: {{$ctrl.user.address_phone_gsm}}<br></span>
        </address>`
})


.component('download', {
    template: `<a ng-transclude ng-class="{'disabled': $ctrl.href != ''}" href='{{$ctrl.href}}'>TEST</a>`,
    bindings: {
        url: '<',
        filename: '<'
    },
    transclude: true,
    controller: function(ClariwebAuth) {
        this.$onInit = () => {
            this.href = '';
        };
        this.$onChanges = () => {
            if (this.filename && this.url) {
                let sessionid = ClariwebAuth.get_sessionid();
                if (sessionid !== null) {
                    this.href = this.url + '/' + this.filename + "?sessionid=" + sessionid;
                }
            } else {
                this.href = '';
            }
        };
    }
})

.component('analyses', {
    transclude: true,
    bindings: {
        analyses: "<",
        chevron: '<'
    },
    template: require('../partials/analyses.tpl.html'),
    controller: function() {
        // This was pushed to angular templateCache prior to running
        // the directive
        this.popover_template = 'partials/analyse_popover.tpl.html';
        this.isAnormal = (analyse ) => {
            return (angular.isDefined(analyse) && analyse.anormaux.length > 0);
        };
        this.isEncours = (analyse) => {
            return (angular.isDefined(analyse) && analyse.a_saisir);
        };
        this.getAnalyseLabel = (analyse) => {
            if (this.isAnormal(analyse)) {
                return 'label-warning';
            } else if (!this.isEncours(analyse)) {
                return 'label-success';
            } else {
                return 'label-default';
            }
        };
    }
})

.component('anormaliteIcon', {
    transclude: true,
    template: require('../partials/anormalite.tpl.html'),
    bindings: {
        indicationnormalite: '<'
    },
    controller: function() {
        this.popover_template = 'partials/anormalite_popover.tpl.html';
    }
})

;