angular.module('clariweb.controllers.documents', [])

.controller(
    'DocumentListCtrl',
    function(ClariwebAuth, Constants,
             $scope, $http, $state, $timeout, $location, $anchorScroll) {
        $scope.inLoad = false;
        $scope.filter = $state.params.filter;
        $scope.showarchive = $state.params.showarchive;
        $scope.currentPage = 1;
        $scope.minlength = 5;
        var fetchTimer = null;
        /* Keep clariweb service list document filter in sync */
        $scope.$watch('filter', function(filter, wasfilter) {
            if (fetchTimer) {
                $timeout.cancel(fetchTimer);
            }
            if (filter === wasfilter) {
                return;
            }
            if (filter && filter.length < $scope.minlength) {
                return;
            }
            fetchTimer = $timeout(function() {
                $scope.currentPage = 1;
                $scope.fetch();
            }, 800);
        });
        $scope.$watch('currentPage', () => { $scope.fetch(); });
        $scope.onselectpage = (page) => {
            $scope.currentPage = page;
        };
        $scope.selectitem = (doc) => {
            if ($scope.canViewDoc(doc)) {
                $state.go('document.detail', {document_id: doc.id});
            }
        };
        /* isForeign document ? (GROUP ?) */
        var isForeign = (document) => {
            return (angular.isDefined(document) &&
                    (document.user.user.first_name !== ClariwebAuth.user.first_name) ||
                    (document.user.user.last_name !== ClariwebAuth.user.last_name));
        };
        $scope.fetch = () => {
            var url;
            if ($scope.inLoad) {
                return;
            }
            $scope.inLoad = true;
            $state.go('document.list', {filter: $scope.filter, showarchive: $scope.showarchive});
            if ($scope.showarchive) {
                url = Constants.API_DOCUMENT_LISTALL;
            } else {
                url = Constants.API_DOCUMENT_LISTNOTSEEN;
            }
            $http({
                method: 'GET',
                url: url,
                params: {
                    search: $scope.filter,
                    page: $scope.currentPage
                }
            })
            .then(
                (response) => {
                    var documents = [];
                    var i;
                    for(i=0; i < response.data.results.length; i++) {
                        var document = response.data.results[i];
                        document.isforeign = isForeign(document);
                        if (! document.analyses) {
                            document.analyses = [];
                        }
                        documents.push(document);
                    }
                    $scope.documents = documents;
                    $scope.inLoad = false;
                    $location.hash("body");
                    $anchorScroll();
                },
                (response) => {
                    if (response.status === 403 || response.status === 401) {
                        /* what the hell ? */
                        $state.go("logout");
                    } else {
                        $scope.documents = [];
                        $scope.inLoad = false;
                    }
                }
            );
        };
        /* Retreive document list */
        $scope.$watch('showarchive', (showarchive, wasshowarchive) => {
            if (showarchive !== wasshowarchive) {
                $scope.fetch();
            }
        });
        $scope.$on("$destroy", () => {
            $timeout.cancel(fetchTimer);
        });
        $scope.canViewDoc = (doc) => {
            if ($scope.settings.DEBPT_MINIMUM_AMOUNT > 0) {
                return (
                    doc.is_invoice ||
                    doc.unpaid_amount <= 0 ||
                    ClariwebAuth.get_debpt() <= $scope.settings.DEBPT_MINIMUM_AMOUNT
                );
            }
            return true;
        };
    }
)

.controller(
    'DocumentDetailCtrl',
    function(Constants, $state, $scope, $http, $timeout, $window, $sce,
             ClariwebAuth) {
        $scope.document_id = $state.params.document_id;
        $scope.pdfURL = null;
        $scope.download_url_with_sid = null;
        $scope.$watch("document", (document) => {
            $scope.download_url = null;
            if (! document) {
                return;
            }
            $scope.download_filename = document.document + "_" +
                document.sil_demande_number + '.pdf';
            $scope.download_url =
                Constants.API_DOCUMENT_DOWNLOAD.replace("{document_id}",
                    document.id);
            $scope.downloadstream_url =
                Constants.API_DOCUMENT_DOWNLOADSTREAM.replace("{document_id}",
                    document.id);
        });
        $scope.$watch("download_url", (url) => {
            if (url) {
                $http.get(url, {
                    responseType: 'arraybuffer'
                }).then(function(response) {
                    var file = new Blob([response.data], {type: 'application/pdf'});
                    var fileURL = URL.createObjectURL(file);
                    $scope.pdfURL = $sce.trustAsResourceUrl(fileURL);
                });
            } else {
                $scope.pdfURL = null;
            }
        });
        $scope.$watch("downloadstream_url", (url) => {
            if (url) {
                $scope.download_url_with_sid =
                    url + "?sessionid=" + ClariwebAuth.get_sessionid();
            } else {
                $scope.download_url_with_sid = null;
            }
        });
        $scope.$watch("document_id", (document_id) => {
            if (document_id) {
                var url = Constants.API_DOCUMENT_DETAIL.replace("{document_id}",
                                                                document_id);
                $http.get(url).then(
                    (response) => {
                        $scope.document = response.data;
                    },
                    (e) => {
                        console.log("Error during load:", e);
                    }
                );
            }
        });

    }
)
;